==> zio-aws-timestreamquery_3-5.17.127.1-sources.jar: zio/aws/timestreamquery/model/CancelQueryResponse.scala <==
package zio.aws.timestreamquery.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import scala.jdk.CollectionConverters.*
final case class CancelQueryResponse(
    cancellationMessage: Option[String] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.timestreamquery.model.CancelQueryResponse = {
    import CancelQueryResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.timestreamquery.model.CancelQueryResponse
      .builder()
      .optionallyWith(
        cancellationMessage.map(value => value: java.lang.String)
      )(_.cancellationMessage)
      .build()
  }
  def asReadOnly: zio.aws.timestreamquery.model.CancelQueryResponse.ReadOnly =
    zio.aws.timestreamquery.model.CancelQueryResponse.wrap(buildAwsValue())
}
object CancelQueryResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.timestreamquery.model.CancelQueryResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.timestreamquery.model.CancelQueryResponse =
      zio.aws.timestreamquery.model
        .CancelQueryResponse(cancellationMessage.map(value => value))
    def cancellationMessage: Option[String]
    def getCancellationMessage: ZIO[Any, AwsError, String] =
      AwsError.unwrapOptionField("cancellationMessage", cancellationMessage)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.timestreamquery.model.CancelQueryResponse
  ) extends zio.aws.timestreamquery.model.CancelQueryResponse.ReadOnly {
    override val cancellationMessage: Option[String] =
      scala.Option(impl.cancellationMessage()).map(value => value: String)
  }
  def wrap(
      impl: software.amazon.awssdk.services.timestreamquery.model.CancelQueryResponse
  ): zio.aws.timestreamquery.model.CancelQueryResponse.ReadOnly = new Wrapper(
    impl
  )
}

==> zio-aws-timestreamquery_3-5.19.31.3-sources.jar: zio/aws/timestreamquery/model/CancelQueryResponse.scala <==
package zio.aws.timestreamquery.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import scala.jdk.CollectionConverters.*
final case class CancelQueryResponse(
    cancellationMessage: Optional[String] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.timestreamquery.model.CancelQueryResponse = {
    import CancelQueryResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.timestreamquery.model.CancelQueryResponse
      .builder()
      .optionallyWith(
        cancellationMessage.map(value => value: java.lang.String)
      )(_.cancellationMessage)
      .build()
  }
  def asReadOnly: zio.aws.timestreamquery.model.CancelQueryResponse.ReadOnly =
    zio.aws.timestreamquery.model.CancelQueryResponse.wrap(buildAwsValue())
}
object CancelQueryResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.timestreamquery.model.CancelQueryResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.timestreamquery.model.CancelQueryResponse =
      zio.aws.timestreamquery.model
        .CancelQueryResponse(cancellationMessage.map(value => value))
    def cancellationMessage: Optional[String]
    def getCancellationMessage: ZIO[Any, AwsError, String] =
      AwsError.unwrapOptionField("cancellationMessage", cancellationMessage)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.timestreamquery.model.CancelQueryResponse
  ) extends zio.aws.timestreamquery.model.CancelQueryResponse.ReadOnly {
    override val cancellationMessage: Optional[String] = zio.aws.core.internal
      .optionalFromNullable(impl.cancellationMessage())
      .map(value => value: String)
  }
  def wrap(
      impl: software.amazon.awssdk.services.timestreamquery.model.CancelQueryResponse
  ): zio.aws.timestreamquery.model.CancelQueryResponse.ReadOnly = new Wrapper(
    impl
  )
}
